@@ -7,6 +7,7 @@ from typing import List
 
 from notecoin.okex.websocket.handle import BaseHandle
 from notecoin.okex.websocket.utils import get_local_timestamp
+from notetool.secret import read_secret
 
 from websocket import WebSocket, WebSocketException, create_connection
 
@@ -15,9 +16,9 @@ class BaseConnect:
     def __init__(self, url, channels, api_key=None, secret_key=None, passphrase=None, private=False):
         self.url = url
         self.channels = channels
-        self.api_key = api_key
-        self.secret_key = secret_key
-        self.passphrase = passphrase
+        self.api_key = api_key or read_secret(cate1='coin', cate2='okex', cate3='api_key')
+        self.secret_key = secret_key or read_secret(cate1='coin', cate2='okex', cate3='secret_key')
+        self.passphrase = passphrase or read_secret(cate1='coin', cate2='okex', cate3='passphrase')
         self.private = private
         self.ws: WebSocket = create_connection(self.url)
         self.handles: List[BaseHandle] = []
